@@ -406,62 +406,62 @@ int write_configuration(char* fname){
   if ( file.fail() ) return FALSE;
 
   for ( int i = 0 ; i < syslogs ; i++ ){
-    if ( syslog[i]->mode == TAIL_FILE ) file << "TAIL{";
-    else if ( syslog[i]->mode == CAT_FILE ) file << "CAT{";
-    file << syslog[i]->filename << ",";
-    file << syslog[i]->interval << ",";
-    file << syslog[i]->buttontext << ",";
-    file << syslog[i]->help << "}" << endl;
+    if ( entry[i]->mode == TAIL_FILE ) file << "TAIL{";
+    else if ( entry[i]->mode == CAT_FILE ) file << "CAT{";
+    file << entry[i]->filename << ",";
+    file << entry[i]->interval << ",";
+    file << entry[i]->buttontext << ",";
+    file << entry[i]->help << "}" << endl;
 
-    if ( syslog[i]->filter != NULL ){
+    if ( entry[i]->filter != NULL ){
       int a = 0;
-      while ( syslog[i]->filter[a] != NULL ){
+      while ( entry[i]->filter[a] != NULL ){
 	int fe = 0;
-	if ( syslog[i]->filter[a]->mode & RAISE ){
+	if ( entry[i]->filter[a]->mode & RAISE ){
 	  file << "RAISE";
 	  fe++;
 	}
 	
-	if ( syslog[i]->filter[a]->mode & LOWER ){
+	if ( entry[i]->filter[a]->mode & LOWER ){
 	  if ( fe > 0 ) file << ",";
 	  file << "LOWER";
 	  fe++;
 	}
 
-	if ( syslog[i]->filter[a]->mode & HIDE ){
+	if ( entry[i]->filter[a]->mode & HIDE ){
 	  if ( fe > 0 ) file << ",";
 	  file << "HIDE";
 	  fe++;
 	}
 	
-	if ( syslog[i]->filter[a]->mode & ALERT ){
+	if ( entry[i]->filter[a]->mode & ALERT ){
 	  if ( fe > 0 ) file << ",";
 	  file << "ALERT";
 	  fe++;
 	}
 	
-	if ( syslog[i]->filter[a]->mode & NOTICE ){
+	if ( entry[i]->filter[a]->mode & NOTICE ){
 	  if ( fe > 0 ) file << ",";
 	  file << "NOTICE";
 	  fe++;
 	}
 	
-	if ( syslog[i]->filter[a]->mode & UNICONIFY ){
+	if ( entry[i]->filter[a]->mode & UNICONIFY ){
 	  if ( fe > 0 ) file << ",";
 	  file << "UNICONIFY";
 	  fe++;
 	}
 
-	if ( syslog[i]->filter[a]->mode & EXECUTE ){
+	if ( entry[i]->filter[a]->mode & EXECUTE ){
 	  if ( fe > 0 ) file << ",";
 	  file << "EXECUTE";
 	  fe++;
 	}
 	
-	file << "{" << syslog[i]->filter[a]->string << "}";
+	file << "{" << entry[i]->filter[a]->string << "}";
 	
-	if ( syslog[i]->filter[a]->mode & EXECUTE )
-	  file << "{" << syslog[i]->filter[a]->execline << "}";
+	if ( entry[i]->filter[a]->mode & EXECUTE )
+	  file << "{" << entry[i]->filter[a]->execline << "}";
 	
 	file << endl;
 	
