@@ -404,12 +404,12 @@ void create_form(){
   gtk_box_pack_end(GTK_BOX(big_box), notebook, TRUE, TRUE, 5);
   gtk_widget_show(notebook);
   for ( int i =  0 ; i < syslogs ; i++ )
-    insert_page(syslog[i]->filename,
-		syslog[i]->buttontext,
-		syslog[i]->help,
-		syslog[i]->interval,
-		syslog[i]->mode,
-		(Filter** )(syslog[i]->filter),
+    insert_page(entry[i]->filename,
+		entry[i]->buttontext,
+		entry[i]->help,
+		entry[i]->interval,
+		entry[i]->mode,
+		(Filter** )(entry[i]->filter),
 		i);
   gtk_notebook_set_page (GTK_NOTEBOOK(notebook), active); // start at active entry
 
