@@ -45,25 +45,25 @@
 void activate(){
   if ( display_logs == DISABLED ) return;
   /* speedup fadedown for activated logfile */
-  syslog[active]->fadestep = -1 * ( fade_base / 3 );
+  entry[active]->fadestep = -1 * ( fade_base / 3 );
   
-  if ( syslog[active]->filterclass & CLASS1_FILTER ){
+  if ( entry[active]->filterclass & CLASS1_FILTER ){
 /*{{{  There are CLASS1 filters for this one...  */
     
-    if ( syslog[active]->got == -1 ){
-      file_error(syslog[active]->filename);
+    if ( entry[active]->got == -1 ){
+      file_error(entry[active]->filename);
       return;
     }
 
     /* Freeze for output: */
     gtk_text_freeze (GTK_TEXT(textwindow));
     
-    if ( syslog[active]->mode == TAIL_FILE ){
-      output_text(textwindow, syslog[active]->buffer, syslog[active]->length);
+    if ( entry[active]->mode == TAIL_FILE ){
+      output_text(textwindow, entry[active]->buffer, entry[active]->length);
     }  else {
       // for cat the data stays in the read buffer... we don't keep a history
       // anyways.
-      output_text(textwindow, syslog[active]->rbuffer, syslog[active]->length);
+      output_text(textwindow, entry[active]->rbuffer, entry[active]->length);
     }
 
     /* And now unfreeze again */
@@ -73,22 +73,22 @@ void activate(){
 			     GTK_TEXT(textwindow)->vadj->upper - 
 			     GTK_TEXT(textwindow)->vadj->page_size);
 
-    syslog[active]->active = TRUE;
+    entry[active]->active = TRUE;
 
 /*}}}*/
   } else {
 
-    if ( syslog[active]->mode == TAIL_FILE ){
+    if ( entry[active]->mode == TAIL_FILE ){
 /*{{{  Startup of "tail" mode  */
-      syslog[active]->fd = open(syslog[active]->filename, O_RDONLY);
-      if ( syslog[active]->fd == -1 ){
-	file_error(syslog[active]->filename);
+      entry[active]->fd = open(entry[active]->filename, O_RDONLY);
+      if ( entry[active]->fd == -1 ){
+	file_error(entry[active]->filename);
 	return;
       }
       
-      lseek(syslog[active]->fd, -maxtext, SEEK_END);
+      lseek(entry[active]->fd, -maxtext, SEEK_END);
       
-      long got = read(syslog[active]->fd, read_buffer, maxtext);
+      long got = read(entry[active]->fd, read_buffer, maxtext);
       
       /* Freeze for output: */
       gtk_text_freeze (GTK_TEXT(textwindow));
@@ -103,27 +103,27 @@ void activate(){
 			       GTK_TEXT(textwindow)->vadj->page_size);
       
       // Memorize size of logfile...
-      fstat( syslog[active]->fd,  &status );
-      syslog[active]->last_size = status.st_size;
+      fstat( entry[active]->fd,  &status );
+      entry[active]->last_size = status.st_size;
       
-      syslog[active]->tag = gtk_timeout_add (syslog[active]->interval*100,
+      entry[active]->tag = gtk_timeout_add (entry[active]->interval*100,
 					     *tail_interrupt,
 					     (gpointer*) active);
       
-      syslog[active]->active = TRUE;
+      entry[active]->active = TRUE;
 
 /*}}}*/
-    } else if ( syslog[active]->mode == CAT_FILE ){
+    } else if ( entry[active]->mode == CAT_FILE ){
 /*{{{  Startup of "cat" mode  */
-      syslog[active]->fd = open(syslog[active]->filename, O_RDONLY);
-      if ( syslog[active]->fd == -1 ){
-	file_error(syslog[active]->filename);
+      entry[active]->fd = open(entry[active]->filename, O_RDONLY);
+      if ( entry[active]->fd == -1 ){
+	file_error(entry[active]->filename);
 	return;
       }
       
-      long got = read(syslog[active]->fd, read_buffer, maxtext);
+      long got = read(entry[active]->fd, read_buffer, maxtext);
       
-      close(syslog[active]->fd);
+      close(entry[active]->fd);
       
       /* Freeze for output: */
       gtk_text_freeze (GTK_TEXT(textwindow));
@@ -136,18 +136,18 @@ void activate(){
       gtk_adjustment_set_value(GTK_TEXT(textwindow)->vadj,
 			       GTK_TEXT(textwindow)->vadj->lower);
       
-      syslog[active]->tag = gtk_timeout_add (syslog[active]->interval*100,
+      entry[active]->tag = gtk_timeout_add (entry[active]->interval*100,
 					     *cat_interrupt,
 					     (gpointer*) active);
 
-      syslog[active]->active = TRUE;  
+      entry[active]->active = TRUE;  
  
 /*}}}*/
     }
 
   }
   // Set title to button text:
-  gtk_window_set_title (GTK_WINDOW (window), syslog[active]->buttontext );  
+  gtk_window_set_title (GTK_WINDOW (window), entry[active]->buttontext );  
 }
 /*}}}*/
 /*{{{  deactivate()  */
@@ -155,15 +155,15 @@ void deactivate(){
   /*
     We need to disable interrupt-routines...
   */
-  syslog[active]->active = FALSE;
+  entry[active]->active = FALSE;
 
-  if ( ! ( syslog[active]->filterclass & CLASS1_FILTER ) ){
-    if ( syslog[active]->tag != 0 ){
-      gtk_timeout_remove(syslog[active]->tag);
-      syslog[active]->tag=0;
+  if ( ! ( entry[active]->filterclass & CLASS1_FILTER ) ){
+    if ( entry[active]->tag != 0 ){
+      gtk_timeout_remove(entry[active]->tag);
+      entry[active]->tag=0;
     }
-    if ( syslog[active]->mode == TAIL_FILE )
-      close(syslog[active]->fd);
+    if ( entry[active]->mode == TAIL_FILE )
+      close(entry[active]->fd);
   }
 
   /*
@@ -180,14 +180,14 @@ void deactivate(){
 /*{{{  tail_interrupt  */
 int tail_interrupt(gpointer data){ 
   // if the size didn't change we don't need to do anything...
-  fstat( syslog[active]->fd,  &status );
-  if ( status.st_size == syslog[active]->last_size ) return TRUE;
+  fstat( entry[active]->fd,  &status );
+  if ( status.st_size == entry[active]->last_size ) return TRUE;
   /* if file shrunk there was probably a logfile rotation
      so just try to reopen the new one */ 
-  if ( status.st_size < syslog[active]->last_size )
+  if ( status.st_size < entry[active]->last_size )
     if ( reopen_logfile(active) == FALSE ) return TRUE;
 
-  long got = read(syslog[active]->fd, read_buffer, maxtext);
+  long got = read(entry[active]->fd, read_buffer, maxtext);
 
   while ( got > 0 ){
     /* Freeze for these actions: */
@@ -221,25 +221,25 @@ int tail_interrupt(gpointer data){
 			     GTK_TEXT(textwindow)->vadj->upper - 
 			     old_value);
     
-    got = read(syslog[active]->fd, read_buffer, maxtext);
+    got = read(entry[active]->fd, read_buffer, maxtext);
   }
 
-  fstat( syslog[active]->fd,  &status );
-  syslog[active]->last_size = status.st_size;
+  fstat( entry[active]->fd,  &status );
+  entry[active]->last_size = status.st_size;
 
   return TRUE;
 }
 /*}}}*/
 /*{{{  cat_interrupt  */
 int cat_interrupt(gpointer data){
-  syslog[active]->fd = open(syslog[active]->filename, O_RDONLY);
-  if ( syslog[active]->fd == -1 ){
+  entry[active]->fd = open(entry[active]->filename, O_RDONLY);
+  if ( entry[active]->fd == -1 ){
     deactivate();
-    file_error(syslog[active]->filename);
+    file_error(entry[active]->filename);
     return FALSE;
   }
-  long got = read(syslog[active]->fd, read_buffer, maxtext);
-  close( syslog[active]->fd );
+  long got = read(entry[active]->fd, read_buffer, maxtext);
+  close( entry[active]->fd );
   
   /* Freeze textwindow: */
   gtk_text_freeze (GTK_TEXT(textwindow));
@@ -268,33 +268,33 @@ int cat_interrupt(gpointer data){
 /*{{{  shared routines  */
 /* try to reopen logfile */
 int reopen_logfile(int i ){
-  close(syslog[i]->fd);
-  syslog[i]->fd = open(syslog[i]->filename, O_RDONLY);
+  close(entry[i]->fd);
+  entry[i]->fd = open(entry[i]->filename, O_RDONLY);
  
-  if ( syslog[active]->fd > -1 ){
+  if ( entry[active]->fd > -1 ){
     // now we need to go to the beginning of the file:
-    lseek(syslog[i]->fd, 0, SEEK_SET);
+    lseek(entry[i]->fd, 0, SEEK_SET);
     // everything clear... return
     return TRUE;
   }
 
   /* we got a file opening error */
 
-  syslog[i]->got = -1;
+  entry[i]->got = -1;
 
   if ( i == active ) deactivate();
 
-  if ( syslog[i]->filterclass & CLASS1_FILTER  ){
-    gtk_timeout_remove(syslog[i]->wd_tag);
-    syslog[i]->wd_tag = 0;
-    if ( syslog[i]->buffer != NULL ) delete syslog[i]->buffer;
-    syslog[i]->buffer = NULL;
-    if ( syslog[i]->rbuffer != NULL ) delete syslog[i]->rbuffer;
-    syslog[i]->rbuffer = NULL;
-    syslog[i]->length = 0;
+  if ( entry[i]->filterclass & CLASS1_FILTER  ){
+    gtk_timeout_remove(entry[i]->wd_tag);
+    entry[i]->wd_tag = 0;
+    if ( entry[i]->buffer != NULL ) delete entry[i]->buffer;
+    entry[i]->buffer = NULL;
+    if ( entry[i]->rbuffer != NULL ) delete entry[i]->rbuffer;
+    entry[i]->rbuffer = NULL;
+    entry[i]->length = 0;
   }
 
-  file_error(syslog[i]->filename);
+  file_error(entry[i]->filename);
   return FALSE;
 }
 /*}}}*/
@@ -303,58 +303,58 @@ int reopen_logfile(int i ){
 void start_watchdog(){
   int i;
   for ( i = 0 ; i < syslogs ; i++ ){
-    if ( syslog[i]->filterclass & CLASS1_FILTER ){
+    if ( entry[i]->filterclass & CLASS1_FILTER ){
       // we need this buffer ONLY for the tail mode !
-      if ( syslog[i]->mode == TAIL_FILE ){
-	syslog[i]->buffer = new char[maxtext];
+      if ( entry[i]->mode == TAIL_FILE ){
+	entry[i]->buffer = new char[maxtext];
       }
-      syslog[i]->rbuffer = new char[syslog[i]->chunk];
-      syslog[i]->length = 0;
+      entry[i]->rbuffer = new char[entry[i]->chunk];
+      entry[i]->length = 0;
       
-      syslog[i]->fd = open(syslog[i]->filename, O_RDONLY);
+      entry[i]->fd = open(entry[i]->filename, O_RDONLY);
       
-      if ( syslog[i]->mode == TAIL_FILE ){
-	lseek(syslog[i]->fd, -maxtext, SEEK_END);
-	syslog[i]->length = read(syslog[i]->fd, syslog[i]->buffer, maxtext);
+      if ( entry[i]->mode == TAIL_FILE ){
+	lseek(entry[i]->fd, -maxtext, SEEK_END);
+	entry[i]->length = read(entry[i]->fd, entry[i]->buffer, maxtext);
       } else {
-	syslog[i]->length = read(syslog[i]->fd, syslog[i]->rbuffer, maxtext);
+	entry[i]->length = read(entry[i]->fd, entry[i]->rbuffer, maxtext);
       }  
       
-      if ( syslog[i]->mode == TAIL_FILE ){
+      if ( entry[i]->mode == TAIL_FILE ){
 	// Memorize size of logfile...
-	fstat( syslog[i]->fd,  &status );
-	syslog[i]->last_size = status.st_size;
+	fstat( entry[i]->fd,  &status );
+	entry[i]->last_size = status.st_size;
       } else {
-	close(syslog[i]->fd);
+	close(entry[i]->fd);
       }
       
-      syslog[i]->wd_tag = gtk_timeout_add (syslog[i]->interval*100,
+      entry[i]->wd_tag = gtk_timeout_add (entry[i]->interval*100,
 					   *watchdog_interrupt,
 					   (gpointer*) i);
       
     } else {
-      if ( syslog[i]->buffer != NULL ) delete syslog[i]->buffer;
-      syslog[i]->buffer = NULL;
-      if ( syslog[i]->rbuffer != NULL ) delete syslog[i]->rbuffer;
-      syslog[i]->rbuffer = NULL;
+      if ( entry[i]->buffer != NULL ) delete entry[i]->buffer;
+      entry[i]->buffer = NULL;
+      if ( entry[i]->rbuffer != NULL ) delete entry[i]->rbuffer;
+      entry[i]->rbuffer = NULL;
     }
   }
 }
 void stop_watchdog(){
   int i;
   for ( i = 0 ; i < syslogs ; i++ )
-    if ( syslog[i]->filterclass & CLASS1_FILTER ){
-      gtk_timeout_remove(syslog[i]->wd_tag);
-      syslog[i]->wd_tag = 0;
+    if ( entry[i]->filterclass & CLASS1_FILTER ){
+      gtk_timeout_remove(entry[i]->wd_tag);
+      entry[i]->wd_tag = 0;
      
-      if ( syslog[i]->mode == TAIL_FILE )
-	close(syslog[i]->fd);
+      if ( entry[i]->mode == TAIL_FILE )
+	close(entry[i]->fd);
       
-      if ( syslog[i]->buffer != NULL ) delete syslog[i]->buffer;
-      syslog[i]->buffer = NULL;
-      if ( syslog[i]->rbuffer != NULL ) delete syslog[i]->rbuffer;
-      syslog[i]->rbuffer = NULL;
-      syslog[i]->length = 0;
+      if ( entry[i]->buffer != NULL ) delete entry[i]->buffer;
+      entry[i]->buffer = NULL;
+      if ( entry[i]->rbuffer != NULL ) delete entry[i]->rbuffer;
+      entry[i]->rbuffer = NULL;
+      entry[i]->length = 0;
     } 
 }
 /*}}}*/
@@ -363,25 +363,25 @@ void stop_watchdog(){
 int watchdog_interrupt(gpointer data){ 
   int i = (int) data;
 
-  if ( syslog[i]->mode == TAIL_FILE ){
-    if ( syslog[i]->fd == -1 ){
+  if ( entry[i]->mode == TAIL_FILE ){
+    if ( entry[i]->fd == -1 ){
       watchdog_file_error(i);
       return TRUE;
     }
 
     /* tail file */
-    fstat( syslog[i]->fd,  &status );
-    if ( status.st_size == syslog[i]->last_size ) return TRUE;
+    fstat( entry[i]->fd,  &status );
+    if ( status.st_size == entry[i]->last_size ) return TRUE;
     /* if file shrunk there was probably a logfile rotation
        so just try to reopen the new one */ 
-    if ( status.st_size < syslog[i]->last_size )
+    if ( status.st_size < entry[i]->last_size )
       if ( reopen_logfile(i) == FALSE ) return TRUE;
 
   } else {
 
     /* cat file */
-    syslog[i]->fd = open(syslog[i]->filename, O_RDONLY);    
-    if ( syslog[i]->fd == -1 ){
+    entry[i]->fd = open(entry[i]->filename, O_RDONLY);    
+    if ( entry[i]->fd == -1 ){
       /* we got a file opening error */
       watchdog_file_error(i);
       return TRUE;      
@@ -389,32 +389,32 @@ int watchdog_interrupt(gpointer data){
     
   }
   
-  long got = read(syslog[i]->fd, syslog[i]->rbuffer, syslog[i]->chunk);
+  long got = read(entry[i]->fd, entry[i]->rbuffer, entry[i]->chunk);
 
-  if ( syslog[i]->mode == CAT_FILE ) 
-    close( syslog[i]->fd );
+  if ( entry[i]->mode == CAT_FILE ) 
+    close( entry[i]->fd );
 
   while ( got > 0 ){
     long overlap;
 
-    if ( syslog[i]->mode == TAIL_FILE ){
+    if ( entry[i]->mode == TAIL_FILE ){
 
-      overlap= ( got + syslog[i]->length ) - maxtext;
+      overlap= ( got + entry[i]->length ) - maxtext;
       if ( overlap < 0 ) overlap = 0;
       if ( overlap > 0 ){
-	for ( long y = overlap ; y < syslog[i]->length ; y++ )
-	  syslog[i]->buffer[ y - overlap] = syslog[i]->buffer[ y ];
+	for ( long y = overlap ; y < entry[i]->length ; y++ )
+	  entry[i]->buffer[ y - overlap] = entry[i]->buffer[ y ];
       }
       
-      long target = syslog[i]->length - overlap;
+      long target = entry[i]->length - overlap;
       for ( long z = 0 ; z < got ; z++ )
-	syslog[i]->buffer[ z + target ] = syslog[i]->rbuffer[z];
-      syslog[i]->length += got;
-      if ( syslog[i]->length > maxtext ) syslog[i]->length = maxtext;
+	entry[i]->buffer[ z + target ] = entry[i]->rbuffer[z];
+      entry[i]->length += got;
+      if ( entry[i]->length > maxtext ) entry[i]->length = maxtext;
 
     } else {
       
-      syslog[i]->length = got;
+      entry[i]->length = got;
       
     }
     
@@ -428,22 +428,22 @@ int watchdog_interrupt(gpointer data){
     /* NOTICE */
     for ( a = 0 ; a < got ; a++ ){
       f = 0;
-      while ( syslog[i]->filter[f] != NULL ){
-	if ( syslog[i]->filter[f]->mode & NOTICE ){
-	  if ( does_match(syslog[i]->rbuffer, syslog[i]->filter[f]->pattern,
+      while ( entry[i]->filter[f] != NULL ){
+	if ( entry[i]->filter[f]->mode & NOTICE ){
+	  if ( does_match(entry[i]->rbuffer, entry[i]->filter[f]->pattern,
 			  a, got ) == TRUE ){
 	    long b,c;
 	    b = c = a;
-	    while ( b > 0 && syslog[i]->rbuffer[b] != '\n' && syslog[i]->rbuffer[b] != '\r' ) b--;
+	    while ( b > 0 && entry[i]->rbuffer[b] != '\n' && entry[i]->rbuffer[b] != '\r' ) b--;
 	    if ( b != 0 ) b++;
-	    while ( c < got && syslog[i]->rbuffer[c] != '\n' && syslog[i]->rbuffer[c] != '\r' ) c++;
+	    while ( c < got && entry[i]->rbuffer[c] != '\n' && entry[i]->rbuffer[c] != '\r' ) c++;
 	    
 	    gchar* string = new gchar[(c-b)+4];
 	    long d = 0;
-	    for ( ; b < c ; b++ ) string[d++] = syslog[i]->rbuffer[b];
+	    for ( ; b < c ; b++ ) string[d++] = entry[i]->rbuffer[b];
 	    string[d++] = 0;
 	    
-	    notice_alert(syslog[i]->buttontext , string);
+	    notice_alert(entry[i]->buttontext , string);
 	    delete string;
 	    play(NOTICE);
 	  }
@@ -455,9 +455,9 @@ int watchdog_interrupt(gpointer data){
     /* ALERT */
     for ( a = 0 ; a < got ; a++ ){
       f = 0;
-      while ( syslog[i]->filter[f] != NULL ){
-	if ( syslog[i]->filter[f]->mode & ALERT ){
-	  if ( does_match(syslog[i]->rbuffer, syslog[i]->filter[f]->pattern,
+      while ( entry[i]->filter[f] != NULL ){
+	if ( entry[i]->filter[f]->mode & ALERT ){
+	  if ( does_match(entry[i]->rbuffer, entry[i]->filter[f]->pattern,
 			  a, got ) == TRUE ){
 	    trigger_alert(i);
 	    play(ALERT);
@@ -470,9 +470,9 @@ int watchdog_interrupt(gpointer data){
     /* UNICONIFY */
     for ( a = 0 ; a < got ; a++ ){
       f = 0;
-      while ( syslog[i]->filter[f] != NULL ){
-	if ( syslog[i]->filter[f]->mode & UNICONIFY ){
-	  if ( does_match(syslog[i]->rbuffer, syslog[i]->filter[f]->pattern,
+      while ( entry[i]->filter[f] != NULL ){
+	if ( entry[i]->filter[f]->mode & UNICONIFY ){
+	  if ( does_match(entry[i]->rbuffer, entry[i]->filter[f]->pattern,
 			  a, got ) == TRUE ){
 	    /* This maps the window, which also de-iconifies it according to ICCCM. */
 	    gdk_window_show (GTK_WIDGET (window)->window);
@@ -487,19 +487,19 @@ int watchdog_interrupt(gpointer data){
     /* EXECUTE */
     for ( a = 0 ; a < got ; a++ ){
       f = 0;
-      while ( syslog[i]->filter[f] != NULL ){
-	if ( syslog[i]->filter[f]->mode & EXECUTE ){
-	  if ( does_match(syslog[i]->rbuffer, syslog[i]->filter[f]->pattern,
+      while ( entry[i]->filter[f] != NULL ){
+	if ( entry[i]->filter[f]->mode & EXECUTE ){
+	  if ( does_match(entry[i]->rbuffer, entry[i]->filter[f]->pattern,
 			  a, got ) == TRUE ){
 	    long b,c;
 	    b = c = a;
-	    while ( b > 0 && syslog[i]->rbuffer[b] != '\n' && syslog[i]->rbuffer[b] != '\r' ) b--;
+	    while ( b > 0 && entry[i]->rbuffer[b] != '\n' && entry[i]->rbuffer[b] != '\r' ) b--;
 	    if ( b != 0 ) b++;
-	    while ( c < got && syslog[i]->rbuffer[c] != '\n' && syslog[i]->rbuffer[c] != '\r' ) c++;
+	    while ( c < got && entry[i]->rbuffer[c] != '\n' && entry[i]->rbuffer[c] != '\r' ) c++;
 	    
 	    gchar* string = new gchar[(c-b)+4];
 	    long d = 0;
-	    for ( ; b < c ; b++ ) string[d++] = syslog[i]->rbuffer[b];
+	    for ( ; b < c ; b++ ) string[d++] = entry[i]->rbuffer[b];
 	    string[d++] = 0;
 	    
 	    execute_program(i, f , string);
@@ -514,21 +514,21 @@ int watchdog_interrupt(gpointer data){
     /*
       Is the log active ? Then display it ...
     */
-    if ( syslog[i]->active == TRUE ){
-      if ( syslog[i]->mode == TAIL_FILE )
-	append_text(syslog[i]->rbuffer, got);
+    if ( entry[i]->active == TRUE ){
+      if ( entry[i]->mode == TAIL_FILE )
+	append_text(entry[i]->rbuffer, got);
       else
-	replace_text(syslog[i]->rbuffer, got);
+	replace_text(entry[i]->rbuffer, got);
 
     }
     
-    if ( syslog[i]->mode == TAIL_FILE ) got = read(syslog[i]->fd, syslog[i]->rbuffer, syslog[i]->chunk);
+    if ( entry[i]->mode == TAIL_FILE ) got = read(entry[i]->fd, entry[i]->rbuffer, entry[i]->chunk);
     else got = 0;
   }
   
-  if ( syslog[i]->mode == TAIL_FILE ){
-    fstat( syslog[i]->fd,  &status );
-    syslog[i]->last_size = status.st_size;
+  if ( entry[i]->mode == TAIL_FILE ){
+    fstat( entry[i]->fd,  &status );
+    entry[i]->last_size = status.st_size;
   }
   
   return TRUE;
@@ -589,16 +589,16 @@ void replace_text(char* buffer, long amount){
 /*}}}*/
 /*{{{  error subroutines for watchdog  */
 void watchdog_file_error(gint i){
-  syslog[i]->got = -1;      
+  entry[i]->got = -1;      
   if ( i == active ) deactivate();
-  if ( syslog[i]->wd_tag ) gtk_timeout_remove(syslog[i]->wd_tag);
-  syslog[i]->wd_tag = 0;
-  if ( syslog[i]->buffer != NULL ) delete syslog[i]->buffer;
-  syslog[i]->buffer = NULL;
-  if ( syslog[i]->rbuffer != NULL ) delete syslog[i]->rbuffer;
-  syslog[i]->rbuffer = NULL;
-  syslog[i]->length = 0;
+  if ( entry[i]->wd_tag ) gtk_timeout_remove(entry[i]->wd_tag);
+  entry[i]->wd_tag = 0;
+  if ( entry[i]->buffer != NULL ) delete entry[i]->buffer;
+  entry[i]->buffer = NULL;
+  if ( entry[i]->rbuffer != NULL ) delete entry[i]->rbuffer;
+  entry[i]->rbuffer = NULL;
+  entry[i]->length = 0;
 
-  file_error(syslog[i]->filename);
+  file_error(entry[i]->filename);
 }
 /*}}}*/
