@@ -212,17 +212,17 @@ void create_textwidget(){
 }
 void create_buttons(){
   for ( int i = 0 ; i < syslogs ; i++ ){
-    syslog[i]->button = gtk_button_new_with_label (syslog[i]->buttontext);
-    gtk_signal_connect (GTK_OBJECT (syslog[i]->button), "clicked",
+    entry[i]->button = gtk_button_new_with_label (entry[i]->buttontext);
+    gtk_signal_connect (GTK_OBJECT (entry[i]->button), "clicked",
 			GTK_SIGNAL_FUNC (button_pressed), (gpointer) i );
-    gtk_box_pack_start(GTK_BOX(buttonbox), syslog[i]->button, FALSE, FALSE, 5);
-    gtk_tooltips_set_tip(tooltips, syslog[i]->button, syslog[i]->help,syslog[i]->help);
-    gtk_widget_show(syslog[i]->button);
-    syslog[i]->style = gtk_style_copy(stdstyle);
-    gtk_widget_set_style(syslog[i]->button, syslog[i]->style);
-    gtk_style_unref(syslog[i]->style);
+    gtk_box_pack_start(GTK_BOX(buttonbox), entry[i]->button, FALSE, FALSE, 5);
+    gtk_tooltips_set_tip(tooltips, entry[i]->button, entry[i]->help,entry[i]->help);
+    gtk_widget_show(entry[i]->button);
+    entry[i]->style = gtk_style_copy(stdstyle);
+    gtk_widget_set_style(entry[i]->button, entry[i]->style);
+    gtk_style_unref(entry[i]->style);
   }
-  gtk_widget_grab_focus(syslog[0]->button);
+  gtk_widget_grab_focus(entry[0]->button);
 }
 void button_pressed(GtkWidget *widget, gpointer *data){
   if ( display_logs == DISABLED ) return;
@@ -242,29 +242,29 @@ void about_ready(GtkWidget *widget, gpointer *pointer){
 
 /*{{{  Data management  */
 void setup_logs(){
-  syslog = new Log*[fillups];
+  entry = new Log*[fillups];
 
   for ( int i = 0 ; i < fillups ; i++ ){
-    syslog[i] = new Log;
-    syslog[i]->mode = mode[i];
-    syslog[i]->filename = filename[i];
-    if ( help[i] != NULL ) syslog[i]->help = help[i];
+    entry[i] = new Log;
+    entry[i]->mode = mode[i];
+    entry[i]->filename = filename[i];
+    if ( help[i] != NULL ) entry[i]->help = help[i];
     else{
-      syslog[i]->help = new char[strlen(syslog[i]->filename)];
-      strcpy(syslog[i]->help, syslog[i]->filename);
+      entry[i]->help = new char[strlen(entry[i]->filename)];
+      strcpy(entry[i]->help, entry[i]->filename);
     }
-    syslog[i]->buttontext = buttontext[i];
-    syslog[i]->interval = interval[i];
-    syslog[i]->commandline = commandline[i];
-    syslog[i]->tag = 0;
-    syslog[i]->alert_tag = 0;
-    syslog[i]->buffer = syslog[i]->rbuffer = NULL;
+    entry[i]->buttontext = buttontext[i];
+    entry[i]->interval = interval[i];
+    entry[i]->commandline = commandline[i];
+    entry[i]->tag = 0;
+    entry[i]->alert_tag = 0;
+    entry[i]->buffer = entry[i]->rbuffer = NULL;
 
     // chunk gives the blocksize of the read for the watchdog
     // must be maxtext for anything else than TAIL, of course.
-    syslog[i]->chunk = RDBLCK * syslog[i]->interval;
-    if ( ( syslog[i]->mode != TAIL_FILE ) ||
-	 ( syslog[i]->chunk > maxtext) ) syslog[i]->chunk = maxtext;
+    entry[i]->chunk = RDBLCK * entry[i]->interval;
+    if ( ( entry[i]->mode != TAIL_FILE ) ||
+	 ( entry[i]->chunk > maxtext) ) entry[i]->chunk = maxtext;
 
     /*
       Fillup the filter elements with some mind dizzying memory juggling
@@ -277,21 +277,21 @@ void setup_logs(){
 
       int x = 0;
       while ( f[x] != NULL ) x++;
-      syslog[i]->filter = new Filter*[x+1];
-      syslog[i]->filterclass = NO_FILTER;
+      entry[i]->filter = new Filter*[x+1];
+      entry[i]->filterclass = NO_FILTER;
 
       x = 0;
       while  ( f[x] != NULL ) {
-	syslog[i]->filter[x] = new Filter();
-	syslog[i]->filter[x]->init( f[x], m[x] );
+	entry[i]->filter[x] = new Filter();
+	entry[i]->filter[x]->init( f[x], m[x] );
 	delete f[x];
-	syslog[i]->filter[x]->execline = fe[x];
-	gint fclass = determine_filter_class(syslog[i]->filter[x]->mode);
-	syslog[i]->filterclass |= fclass;
+	entry[i]->filter[x]->execline = fe[x];
+	gint fclass = determine_filter_class(entry[i]->filter[x]->mode);
+	entry[i]->filterclass |= fclass;
 	x++;
       }
-      syslog[i]->filter[x] = NULL; // NULL Termination is crucial...
-      sort_filters(syslog[i]->filter);
+      entry[i]->filter[x] = NULL; // NULL Termination is crucial...
+      sort_filters(entry[i]->filter);
       delete f;
       delete fe;
       delete m;
@@ -316,12 +316,12 @@ void setup_logs(){
 void unsetup_logs(){
   for ( int i = 0 ; i < syslogs ; i++ ){
     remove_alert(i);                                              // clear alert routines & data
-    gtk_widget_destroy(syslog[i]->button);
-    delete syslog[i];
+    gtk_widget_destroy(entry[i]->button);
+    delete entry[i];
   }
-  delete syslog;
+  delete entry;
   syslogs = 0;
-  syslog = NULL;
+  entry = NULL;
 }
 void free_memory(){
   unsetup_logs();
@@ -396,7 +396,12 @@ void sort_filters(Filter** filter){
 
 /*{{{  Initial preparations  */
 /*{{{  Subroutines  */
-void usage(){
+/*
+  outputs usage message
+ */
+void 
+usage()
+{
   cout << endl << "The Xlogmaster - version " << VERSION << ", usage: " << endl << endl;
   cout << "xlogmaster [-activate <n>] [-alertcolor <r,g,b>] ";
   cout << "[-audio <on/off>] [-audio-alert <filename>/<off>] ";
@@ -413,7 +418,12 @@ void usage(){
   cout << endl << endl;
   _exit(0);
 }
-void help_message(){
+/*
+  outputs help message
+*/
+void 
+help_message()
+{
   cout << endl << "The Xlogmaster " << VERSION << endl << endl;
   cout << "The following options are known to the Xlogmaster:" << endl << endl;
   cout << "-help\t\t\tPrint this message and exit" << endl;
@@ -444,7 +454,12 @@ void help_message(){
 
   _exit(0);
 }
-void version_message(){
+/*
+  outputs version message
+*/
+void 
+version_message()
+{
   cout << endl << "The Xlogmaster " << VERSION << endl;
   cout << "Copyright (C) 1998 by Georg C. F. Greve" << endl;
   cout << "This is a GNU program" << endl;
@@ -456,7 +471,13 @@ void version_message(){
   cout << "see the files named COPYING." << endl << endl;
   _exit(0);
 }
-void eval_colorstring(char* string){
+/*
+  evaluates GTK+ colorstring (r,g,b within 0-1) each value sepatared
+  by a ',' and puts the values into the c_alert array.
+*/
+void 
+eval_colorstring(char* string)
+{
   c_alert[0] = c_alert[1] = c_alert[2] = 0;
   int rgb = 0;
   int x = 0;
@@ -479,7 +500,15 @@ void eval_colorstring(char* string){
     x++;
   }
 }
-long get_value(char* string, int* index){
+/*
+  this routine takes a string as the first parameter and starts converting
+  it to a numeric value (understanding b,k,m for bytes, kilobytes, 
+  megabytes). The conversion is started at position "index" (2nd parameter)
+  and the return value is the retrieved numeric value
+*/
+long 
+get_value(char* string, int* index)
+{
   long value = 0;
   int y = *index;
   char a;
@@ -496,8 +525,84 @@ long get_value(char* string, int* index){
   else *index = y;
   return value;
 }
+/*
+  retrieves long commandline option (basically rebuilding the
+  functionality of getopt_long because that function doesn't exist
+  on all UN*X systems.)
+  parameters: argc, argv (as given to main), index: the position of
+  the last found parameter (or 0 if none)
+  return value: 
+  -1 = unknown parameter or no more parameters
+  -2 = "--" found - stop commandline parsing
+  otherwise amount of values retrieved (0 or 1)
+
+  the function parses the commandline and if it doesn't find the
+  commandline string in cmdline_options (see xlogmaster.H) it returns
+  -1. If it does find it, it looks at the next parameter (if existent) and
+  if it is unknown it is considered to be the value for the current one.
+
+*/
+gint
+my_getopt_long(int argc, char* argv[], int* index)
+{
+  cmdline_par = NULL;
+  cmdline_val = NULL;
+
+  if ( *index == 0 ) *index = 1;
+  if (  argv[*index] == NULL ||
+	*index >= argc ) return -1;
+  if ( ! strcmp( argv[*index], "--" )) return -2;
+  
+
+  gint x = getopt_sub( argv[*index] );
+  if ( x == -1 ) return -1;
+  
+  cmdline_par = cmdline_options[x];
+  
+  *index += 1;
+  
+  if (  argv[*index] == NULL ||
+	*index >= argc ) return 0;
+  
+  gint y = getopt_sub( argv[*index] );
+  if ( y != -1 ) return 0;
+  
+  cmdline_val = argv[*index];
+  *index += 1;
+  
+  return 1;
+}
+/* 
+   subroutine for my_getopt_long
+   
+   returns -1 if string could not be found in cmdline_options array
+   return position if string has been found
+*/
+gint
+getopt_sub(gchar* string)
+{
+  gint y = 0;
+  while ( string[y] != 0 &&
+	  string[y] == '-' ) y++; 
+  
+  if ( y == 0 || y > 2 ) return -1;          // only 1 or 2 '-' allowed
+
+  gint x = 0;
+  while ( cmdline_options[x] != NULL )
+    {
+      
+      if (  ! strcmp(&(string[y]), cmdline_options[x]) )
+	return x;
+      
+      x++;
+    }
+  
+  return -1;
+}
 /*}}}*/
-void init(int argc,char* argv[]){
+void 
+init(int argc,char* argv[])
+{
 /*{{{  Set startup defaults  */
   syslogs = 0; // Nothing to display (yet)
   fillups = 0; // When we enter here there is nothing to be filled up by definition
@@ -557,202 +662,203 @@ void init(int argc,char* argv[]){
  strcpy(xlm_path, STYLEDIR);
  strcat(xlm_path, "/scripts:");
  strcat(xlm_path, system_path);
- setenv( "PATH", xlm_path, 1 );
+ my_setenv( "PATH", xlm_path);
  delete xlm_path;
 /*}}}*/
 
 /*{{{  my own commandline things  */
-  gint  x;
-  gint opt_index;
-  int gtkrc = FALSE;
-  terse = FALSE;
+ gint  x;
+ gint opt_index = 0;
+ int gtkrc = FALSE;
+ terse = FALSE;
   
-  x = getopt_long_only(argc, argv, "", options, &opt_index);
-  while ( x != -1 && x != '?' ){
-    const gchar* opt = options[opt_index].name;
-    
-    if ( ! strcmp( opt, "activate" ) )
-      {
-	if ( optarg == NULL ) usage();
-	int index = 0;
-	request_active = get_value( optarg, &index ) - 1 ;
-      } 
-    else if ( ! strcmp( opt, "alertcolor" ) )
-      {
-	if ( optarg == NULL ) usage();
-	eval_colorstring(optarg);
-      } 
-    else if ( ! strcmp( opt, "audio" ))
-      { 
-	if ( optarg == NULL ) usage();
-	if ( ! strcmp( optarg, "on" ) ) sound = TRUE;
-	if ( ! strcmp( optarg, "ON" ) ) sound = TRUE;
-	if ( ! strcmp( optarg, "off" ) ) sound = FALSE;
-	if ( ! strcmp( optarg, "OFF" ) ) sound = FALSE;
-	if ( sound == FALSE ){
-	  if ( alert_sound != NULL ) delete alert_sound;
-	  if ( notice_sound != NULL ) delete notice_sound;
-	  if ( uniconify_sound != NULL ) delete uniconify_sound;
-	  uniconify_sound = notice_sound = alert_sound = NULL;
-	}
-      }
-    else if ( ! strcmp( opt, "audio-alert" ) )
-      { 
-	if ( optarg == NULL ) usage();
-	if ( ! strcmp( optarg, "off" ) ) alert_sound = NULL;
-	else if ( ! strcmp( optarg, "OFF" ) ) alert_sound = NULL;
-	else {
-	  alert_sound = new char[strlen(optarg)+1];
-	  strcpy(alert_sound, optarg);
-	  sound = TRUE;
-	}
-      }
-    else if ( ! strcmp( opt, "audio-notice" ) )
-      { 
-	if ( optarg == NULL ) usage();
-	if ( ! strcmp( optarg, "off" ) ) notice_sound = NULL;
-	else if ( ! strcmp( optarg, "OFF" ) ) notice_sound = NULL;
-	else {
-	  notice_sound = new char[strlen(optarg)+1];
-	  strcpy(notice_sound, optarg);
-	  sound = TRUE;
-	}
-      } 
-    else if ( ! strcmp( opt, "audio-uniconify" ) )
-      { 
-	if ( optarg == NULL ) usage();
-	if ( ! strcmp( optarg, "off" ) ) uniconify_sound = NULL;
-	else if ( ! strcmp( optarg, "OFF" ) ) uniconify_sound = NULL;
-	else {
-	  uniconify_sound = new char[strlen(optarg)+1];
-	  strcpy(uniconify_sound, optarg);
-	  sound = TRUE;
-	}
-      } 
-    else if ( ! strcmp( opt, "buffer" ) )
-      {
-	if ( optarg == NULL ) usage();
-	int index = 0;
-	maxtext = get_value( optarg, &index );
-      }
-    else if ( ! strcmp( opt, "config" ) )
-      {
-	if ( optarg == NULL ) usage();
-	read_configuration(optarg);
-      }
-    else if ( ! strcmp( opt, "fadeseconds" ) )
-      {
-	if ( optarg == NULL ) usage();
-	int index = 0;
-	int seconds = 0;
-	seconds = get_value( optarg, &index );
-	if ( seconds < 1 ) seconds = 1;
-	fade_step = (-1.0 * ( (gdouble) fade_base / ( 10 * seconds )));
-      }
-    else if ( ! strcmp( opt, "fadesteps" ) )
-      {
-	if ( optarg == NULL ) usage();
-	int index = 0;
-	steps = get_value( optarg, &index );
-      }
-    else if ( ! strcmp( opt, "geometry" ) )
-      {
-	if ( optarg == NULL ) usage();
-	int index = 0;
-	char* string = optarg;
-	
-	if ( string[index] != 'x' )
-	  width = get_value( optarg, &index );
-	if ( string[index] == 'x' ){
-	  index++;
-	  height = get_value( optarg, &index );
-	}
-	if ( string[index] == '+' ){
-	  index++;
-	  xpos = get_value( optarg, &index );
-	}
-	if ( string[index] == '+' ){
-	  index++;
-	  ypos = get_value( optarg, &index );
-	}
-      }
-    else if ( ! strcmp( opt, "gtkrc" ) )
-      {
-	if ( optarg == NULL ) usage();
-	gtkrc = TRUE;
-	gtk_rc_parse(optarg);
-      }
-    else if  ( ! strcmp( opt, "help" ) )
-      {
-	help_message();
-      }
+ x = my_getopt_long(argc, argv, &opt_index);
+ while ( x >= 0 ){
+   if ( ! strcmp( cmdline_par, "activate" ) )
+     {
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       int index = 0;
+       request_active = get_value( cmdline_val, &index ) - 1 ;
+     } 
+   else if ( ! strcmp( cmdline_par, "alertcolor" ) )
+     {
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       eval_colorstring(cmdline_val);
+     } 
+   else if ( ! strcmp( cmdline_par, "audio" ))
+     { 
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       if ( ! strcmp( cmdline_val, "on" ) ) sound = TRUE;
+       if ( ! strcmp( cmdline_val, "ON" ) ) sound = TRUE;
+       if ( ! strcmp( cmdline_val, "off" ) ) sound = FALSE;
+       if ( ! strcmp( cmdline_val, "OFF" ) ) sound = FALSE;
+       if ( sound == FALSE ){
+	 if ( alert_sound != NULL ) delete alert_sound;
+	 if ( notice_sound != NULL ) delete notice_sound;
+	 if ( uniconify_sound != NULL ) delete uniconify_sound;
+	 uniconify_sound = notice_sound = alert_sound = NULL;
+       }
+     }
+   else if ( ! strcmp( cmdline_par, "audio-alert" ) )
+     { 
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       if ( ! strcmp( cmdline_val, "off" ) ) alert_sound = NULL;
+       else if ( ! strcmp( cmdline_val, "OFF" ) ) alert_sound = NULL;
+       else {
+	 alert_sound = new char[strlen(cmdline_val)+1];
+	 strcpy(alert_sound, cmdline_val);
+	 sound = TRUE;
+       }
+     }
+   else if ( ! strcmp( cmdline_par, "audio-notice" ) )
+     { 
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       if ( ! strcmp( cmdline_val, "off" ) ) notice_sound = NULL;
+       else if ( ! strcmp( cmdline_val, "OFF" ) ) notice_sound = NULL;
+       else {
+	 notice_sound = new char[strlen(cmdline_val)+1];
+	 strcpy(notice_sound, cmdline_val);
+	 sound = TRUE;
+       }
+     } 
+   else if ( ! strcmp( cmdline_par, "audio-uniconify" ) )
+     { 
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       if ( ! strcmp( cmdline_val, "off" ) ) uniconify_sound = NULL;
+       else if ( ! strcmp( cmdline_val, "OFF" ) ) uniconify_sound = NULL;
+       else {
+	 uniconify_sound = new char[strlen(cmdline_val)+1];
+	 strcpy(uniconify_sound, cmdline_val);
+	 sound = TRUE;
+       }
+     } 
+   else if ( ! strcmp( cmdline_par, "buffer" ) )
+     {
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       int index = 0;
+       maxtext = get_value( cmdline_val, &index );
+     }
+   else if ( ! strcmp( cmdline_par, "config" ) )
+     {
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       read_configuration(cmdline_val);
+     }
+   else if ( ! strcmp( cmdline_par, "fadeseconds" ) )
+     {
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       int index = 0;
+       int seconds = 0;
+       seconds = get_value( cmdline_val, &index );
+       if ( seconds < 1 ) seconds = 1;
+       fade_step = (-1.0 * ( (gdouble) fade_base / ( 10 * seconds )));
+     }
+   else if ( ! strcmp( cmdline_par, "fadesteps" ) )
+     {
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       int index = 0;
+       steps = get_value( cmdline_val, &index );
+     }
+   else if ( ! strcmp( cmdline_par, "geometry" ) )
+     {
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       int index = 0;
+       char* string = cmdline_val;
+       
+       if ( string[index] != 'x' )
+	 width = get_value( cmdline_val, &index );
+       if ( string[index] == 'x' ){
+	 index++;
+	 height = get_value( cmdline_val, &index );
+       }
+       if ( string[index] == '+' ){
+	 index++;
+	 xpos = get_value( cmdline_val, &index );
+       }
+       if ( string[index] == '+' ){
+	 index++;
+	 ypos = get_value( cmdline_val, &index );
+       }
+     }
+   else if ( ! strcmp( cmdline_par, "gtkrc" ) )
+     {
+       if ( cmdline_val == NULL || x == 0 ) usage();
+       gtkrc = TRUE;
+       gtk_rc_parse(cmdline_val);
+     }
+   else if  ( ! strcmp( cmdline_par, "help" ) )
+     {
+       help_message();
+     }
 #if HAVE_MLOCKALL
-    else if ( ! strcmp( opt, "mlockall" ) )
-      { 
-	lockmem = TRUE;
-      }
+   else if ( ! strcmp( cmdline_par, "mlockall" ) )
+     { 
+       if ( x == 1 ) usage();
+       lockmem = TRUE;
+     }
 #endif /* HAVE_MLOCKALL */
-    else if ( ! strcmp( opt, "notice-follows-mouse" ) )
-      { 
-	if ( optarg == NULL )
-	  {
-	    notice_follows_mouse = TRUE;
-	  }
-	else
-	  {
-	    if ( ! strcmp( optarg, "yes" ) ) notice_follows_mouse = TRUE;
-	    if ( ! strcmp( optarg, "YES" ) ) notice_follows_mouse = TRUE;
-	    if ( ! strcmp( optarg, "no" ) ) notice_follows_mouse = FALSE;
-	    if ( ! strcmp( optarg, "NO" ) ) notice_follows_mouse = FALSE;
-	  }
-      }
-    else if ( ! strcmp( opt, "silent" ) )
-      { 
-	sound = FALSE;
-      }
-    else if ( ! strcmp( opt, "smallicon" ) )
-      { 
-	if ( optarg == NULL )
-	  {
-	    small_icon = TRUE;
-	  }
-	else
-	  { 
-	    if ( ! strcmp( optarg, "yes" ) ) small_icon = TRUE;
-	    if ( ! strcmp( optarg, "YES" ) ) small_icon = TRUE;
-	    if ( ! strcmp( optarg, "no" ) ) small_icon = FALSE;
-	    if ( ! strcmp( optarg, "NO" ) ) small_icon = FALSE;
-	  }
-      }
-    else if ( ! strcmp( opt, "terse" ) )
-      { 
-	terse = TRUE;
-      }
-    else if ( ! strcmp( opt, "version" ) )
-      {
-	version_message();
-      }
-    else if ( ! strcmp( opt, "wordwrap" ) )
-      { 
-	if ( optarg == NULL )
-	  {
-	    small_icon = TRUE;
-	  }
-	else
-	  { 
-	    if ( ! strcmp( optarg, "yes" ) ) wordwrap = TRUE;
-	    if ( ! strcmp( optarg, "YES" ) ) wordwrap = TRUE;
-	    if ( ! strcmp( optarg, "no" ) ) wordwrap = FALSE;
-	    if ( ! strcmp( optarg, "NO" ) ) wordwrap = FALSE;
-	  }
-      }
-    
-    x = getopt_long_only(argc, argv, "", options, &opt_index);
-  };
-  
-  if ( optind < argc || x == '?' )
-    usage();
+   else if ( ! strcmp( cmdline_par, "notice-follows-mouse" ) )
+     { 
+       if ( cmdline_val == NULL )
+	 {
+	   notice_follows_mouse = TRUE;
+	 }
+       else
+	 {
+	   if ( ! strcmp( cmdline_val, "yes" ) ) notice_follows_mouse = TRUE;
+	   if ( ! strcmp( cmdline_val, "YES" ) ) notice_follows_mouse = TRUE;
+	   if ( ! strcmp( cmdline_val, "no" ) ) notice_follows_mouse = FALSE;
+	   if ( ! strcmp( cmdline_val, "NO" ) ) notice_follows_mouse = FALSE;
+	 }
+     }
+   else if ( ! strcmp( cmdline_par, "silent" ) )
+     { 
+       if ( x == 1 ) usage();
+       sound = FALSE;
+     }
+   else if ( ! strcmp( cmdline_par, "smallicon" ) )
+     { 
+       if ( cmdline_val == NULL )
+	 {
+	   small_icon = TRUE;
+	 }
+       else
+	 { 
+	   if ( ! strcmp( cmdline_val, "yes" ) ) small_icon = TRUE;
+	   if ( ! strcmp( cmdline_val, "YES" ) ) small_icon = TRUE;
+	   if ( ! strcmp( cmdline_val, "no" ) ) small_icon = FALSE;
+	   if ( ! strcmp( cmdline_val, "NO" ) ) small_icon = FALSE;
+	 }
+     }
+   else if ( ! strcmp( cmdline_par, "terse" ) )
+     { 
+       if ( x == 1 ) usage();
+       terse = TRUE;
+     }
+   else if ( ! strcmp( cmdline_par, "version" ) )
+     {
+       version_message();
+     }
+   else if ( ! strcmp( cmdline_par, "wordwrap" ) )
+     { 
+       if ( cmdline_val == NULL )
+	 {
+	   wordwrap = TRUE;
+	 }
+       else
+	 { 
+	   if ( ! strcmp( cmdline_val, "yes" ) ) wordwrap = TRUE;
+	   if ( ! strcmp( cmdline_val, "YES" ) ) wordwrap = TRUE;
+	   if ( ! strcmp( cmdline_val, "no" ) ) wordwrap = FALSE;
+	   if ( ! strcmp( cmdline_val, "NO" ) ) wordwrap = FALSE;
+	 }
+     }
    
+   x = my_getopt_long(argc, argv, &opt_index);
+ };
+ 
+ if ( opt_index < argc && x != -2 )
+   usage();
+
 /*}}}*/
 
 /*{{{  System-wide GTKRC  */
@@ -897,8 +1003,8 @@ void output_text(GtkWidget* target, char* buffer, long size){
   /*
     If no filter has been set we can just output and bail out
    */
-  if ( syslog[active]->filter == NULL ||
-       syslog[active]->filterclass == NO_FILTER ){
+  if ( entry[active]->filter == NULL ||
+       entry[active]->filterclass == NO_FILTER ){
     gtk_text_insert (GTK_TEXT(target),NULL,NULL,NULL,buffer,size);
     return;
   }
@@ -921,10 +1027,10 @@ void output_text(GtkWidget* target, char* buffer, long size){
   while ( stop < size ){
     int action = NO_CHANGE;
     int i = 0;
-    while ( syslog[active]->filter[i] != NULL && action != HIDE ){
-      if ( determine_filter_class(syslog[active]->filter[i]->mode) & CLASS0_FILTER )
-	if ( does_match(buffer, syslog[active]->filter[i]->pattern,
-			stop, size ) == TRUE ) action |= syslog[active]->filter[i]->mode;
+    while ( entry[active]->filter[i] != NULL && action != HIDE ){
+      if ( determine_filter_class(entry[active]->filter[i]->mode) & CLASS0_FILTER )
+	if ( does_match(buffer, entry[active]->filter[i]->pattern,
+			stop, size ) == TRUE ) action |= entry[active]->filter[i]->mode;
       
       i++;
     }
@@ -949,11 +1055,11 @@ void output_text(GtkWidget* target, char* buffer, long size){
 	// we need to search once more for a possible HIDE override
 	for ( long n = start ; n < stop ; n++ ){
 	  i = 0;
-	  while ( syslog[active]->filter[i] != NULL && action != HIDE ){
-	    if ( syslog[active]->filter[i]->mode & HIDE )
-	      if ( does_match(buffer, syslog[active]->filter[i]->pattern,
+	  while ( entry[active]->filter[i] != NULL && action != HIDE ){
+	    if ( entry[active]->filter[i]->mode & HIDE )
+	      if ( does_match(buffer, entry[active]->filter[i]->pattern,
 			      n, size ) == TRUE )
-		action |= syslog[active]->filter[i]->mode;
+		action |= entry[active]->filter[i]->mode;
 	    i++;
 	  }
 	}
